@@ -28,13 +28,14 @@ _liji_inspect(PyObject *self, PyObject *args)
 
     liji_state state = liji_init((char *)json, json_len, str_keys, str_sizes, keys_len);
 
-    PyObject *result_list = PyList_New(2);
+    PyObject *result_list = PyList_New(0);
     while (liji_find_multi_state(&state)) {
         PyObject *py_str = PyString_FromStringAndSize(state.response.result_start, state.response.len);
         PyList_Append(result_list, py_str);
+        Py_DECREF(py_str);
     }
 
-    return Py_BuildValue("O", result_list);
+    return result_list;
 }
 
 
